"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GitHubAppTokenProvider = void 0;
const github_app_auth_1 = require("@electron/github-app-auth");
const SecretProvider_1 = require("../SecretProvider");
class GitHubAppTokenProvider extends SecretProvider_1.SecretProvider {
    constructor(options, secretName = 'GITHUB_TOKEN') {
        super();
        this.options = options;
        this.secretName = secretName;
    }
    loadableContentKey() {
        return `github-installation::${this.options.repo.owner}/${this.options.repo.name}`;
    }
    async loadContent() {
        return null;
    }
    async provideSecrets() {
        const { credsString, repo, permissions } = this.options;
        const creds = (0, github_app_auth_1.appCredentialsFromString)(credsString);
        const token = await (0, github_app_auth_1.getTokenForRepo)(repo, creds, {
            repositoryNames: [repo.name],
            permissions: permissions,
        });
        if (!token) {
            throw new Error(`Failed to generate GitHub token for repo "${repo.owner}/${repo.name}"`);
        }
        return {
            [this.secretName]: token,
        };
    }
}
exports.GitHubAppTokenProvider = GitHubAppTokenProvider;
//# sourceMappingURL=GitHubAppProvider.js.map